/** 
 * @fileoverview This file is to be used for listing all functions and properties of 
 * JavaScript objects: AudioPlayer.
 *
 * @version 1.2 
 */

/**
 * @class AudioPlayer is the object for JIL Audio player capabilities<br>
 * <br>
 * AudioPlayer is a sub-object of <I>Multimedia</I>. AudioPlayer is accessed 
 * directly from the object: Widget.Multimedia.AudioPlayer.XXX
 */
function AudioPlayer()
{
}

AudioPlayer.prototype = new Multimedia();
AudioPlayer.prototype.open = AudioPlayer_open;
AudioPlayer.prototype.play = AudioPlayer_play;
AudioPlayer.prototype.pause = AudioPlayer_pause;
AudioPlayer.prototype.resume = AudioPlayer_resume;
AudioPlayer.prototype.stop = AudioPlayer_stop;


/**
 * This method performs preparation for playing the specified file. 
 * Preparation steps can include validating the presence of the file, 
 * validating the codec, and possibly performing some buffering at the WRT's discretion. 
 * The widget engine is responsible for file caching, etc. 
 * The following protocols are supported by the open() function: "file://", "http://", "https://", and "rtsp://". 
 * If the parameter string doesn't start with the protocol syntax listed above, 
 * the widget engine will search the media files in the widget package. 
 * The file wil be playable after open returns. Note that supported protocols may depend on 
 * operator networks and their service policy. <br>
 * <br>
 * e.g.<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;Widget.Multimedia.AudioPlayer.open("file:///sdcard/sample.mp3");<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;Widget.Multimedia.AudioPlayer.open("sample.mp3");<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;Widget.Multimedia.AudioPlayer.open("http://www.sample.com/sample.mp3");
 * 
 * @param {String} fileUrl The url of the audio file to be played.
 * 
 * @returns
 * @type void
 */

function AudioPlayer_open(fileUrl)
{
    // Exception handling
    if(arguments.length != 1) {
        var obj = new Exception();
        obj.type = "invalid_parameter";
        obj.message = "The input parameter number is wrong";
        throw obj;
    }
    if(fileUrl == null || fileUrl == "") {
        var obj = new Exception();
        obj.type = "invalid_parameter";
        obj.message = "The input url is null";
        throw obj;
    }
    if(typeof(fileUrl) != "string") {
        var obj = new Exception();
        obj.type = "invalid_parameter";
        obj.message = "The input parameter type is invalid";
        throw obj;        
    }

    if(fileUrl.length > 255) {
        var obj = new Exception();
        obj.type = "invalid_parameter";
        obj.message = "The input url is too long";
        throw obj;    
    }

	var query = "fileUrl=" + Widget_encode(fileUrl);
    var aUrl = "aiduoniu023:///Multimedia/AudioPlayer/open?" + query;
    // commandQueue.next(aUrl);
    window.WebViewJavascriptBridge.send(aUrl, function(responseData) {
                                        log('JS got response', responseData)
                                        })

    
}

/**
 * Play the audio which is opened by <i>open</i> function. This call will be ignored if the file is already playing.<br> 
 * <br>
 * e.g.<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;Widget.Multimedia.AudioPlayer.play(5);
 * 
 * @param {Number} repeatTimes an integer value specifies how many times the 
 * media file should be played.
 * 
 * @returns
 * @type void
 */
function AudioPlayer_play(repeatTimes)
{
    
	if(repeatTimes == 0)
		return;

    // Exception handling
    if(arguments.length != 1) {
        var obj = new Exception();
        obj.type = "invalid_parameter";
        obj.message = "The input parameter number is wrong";
        throw obj;
    }
    if(repeatTimes == null) {
        var obj = new Exception();
        obj.type = "invalid_parameter";
        obj.message = "The input repeatTimes is null";
        throw obj;
		}
    if(typeof(repeatTimes) != "number") {
        var obj = new Exception();
        obj.type = "invalid_parameter";
        obj.message = "The input parameter type is invalid";
        throw obj;        
    }
    if(isNaN(repeatTimes) || repeatTimes > 65535 || repeatTimes < 0 ) {
        var obj = new Exception();
        obj.type = "invalid_parameter";
        obj.message = "The input repeatTimes is invalid";
        throw obj;
    }

    var query = "repeatTimes=" + Widget_encode(repeatTimes - 1);
    var aUrl = "aiduoniu023:///Multimedia/AudioPlayer/play?" + query;
    //commandQueue.next(aUrl);
    window.WebViewJavascriptBridge.send(aUrl, function(responseData) {
                                        log('JS got response', responseData)
                                        })

}

/**
 * Pauses the audio which is played by <i>play</i> function.<br> 
 * <br>
 * e.g.<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;Widget.Multimedia.AudioPlayer.pause();
 * 
 * @returns
 * @type void
 */
function AudioPlayer_pause()
{
    // Pause the audio
    var aUrl = "aiduoniu023:///Multimedia/AudioPlayer/pause";
    // commandQueue.next(aUrl);
    window.WebViewJavascriptBridge.send(aUrl, function(responseData) {
                                        log('JS got response', responseData)
                                        })

}

/**
 * Resume the audio which is paused by <i>pause</i> function.<br> 
 * <br>
 * e.g.<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;Widget.Multimedia.AudioPlayer.resume();
 * 
 * @returns
 * @type void
 */
function AudioPlayer_resume()
{
    // Resume the audio
    var aUrl = "aiduoniu023:///Multimedia/AudioPlayer/resume";
    // commandQueue.next(aUrl);
    window.WebViewJavascriptBridge.send(aUrl, function(responseData) {
                                        log('JS got response', responseData)
                                        })

}

/**
 * Stop the audio which is played by <i>play</i> function. <br> 
 * <br>
 * e.g.<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;Widget.Multimedia.AudioPlayer.stop();
 * 
 * @returns
 * @type void
 */
function AudioPlayer_stop()
{
    var aUrl = "aiduoniu023:///Multimedia/AudioPlayer/stop";
    // commandQueue.next(aUrl);
    window.WebViewJavascriptBridge.send(aUrl, function(responseData) {
                                        log('JS got response', responseData)
                                        })

}




function SoundPool() {

}
var gSoundFiles = [1];

SoundPool.prototype = new Multimedia();
SoundPool.prototype.load = SoundPool_load;
SoundPool.prototype.unload = SoundPool_unload;
SoundPool.prototype.play = SoundPool_play;
SoundPool.prototype.stop = SoundPool_stop;

function SoundPool_load(fileUrl) {

    // Exception handling
    if(arguments.length != 1){
        throwException(Widget.ExceptionTypes.INVALID_PARAMETER,'The input parameter number is wrong');
    }
    
    if(fileUrl == null || fileUrl === "")	{
        throwException(Widget.ExceptionTypes.INVALID_PARAMETER,'The input url is null');
    }
    
    if(typeof(fileUrl) != "string") {
        throwException(Widget.ExceptionTypes.INVALID_PARAMETER,'The input parameter type is invalid');
    }
    
    if(fileUrl.length > 255) {
        throwException(Widget.ExceptionTypes.INVALID_PARAMETER,'The input url is too long');
    }

    var query = "fileUrl=" + Widget_encode(fileUrl);
    var aUrl = "aiduoniu023:///Multimedia/SoundPool/load?" + query;
    window.WebViewJavascriptBridge.send(aUrl, function(responseData) {
                                        log('JS got response', responseData)
                                        });


    var lastIndex = gSoundFiles.push(fileUrl);
    return lastIndex - 1;
}

function SoundPool_unload(soundID)
{
    return true;
}

function SoundPool_play(soundID, loopmode) {
    // Exception handling

    if(arguments.length != 2) {
        throwException(Widget.ExceptionTypes.INVALID_PARAMETER,'The input parameter number is wrong');
    }
    
    if(loopmode == null || loopmode === '' ) {
        throwException(Widget.ExceptionTypes.INVALID_PARAMETER,'The input loopmode is null');
	}
    if(typeof(loopmode) != "number") {
        throwException(Widget.ExceptionTypes.INVALID_PARAMETER,'The input parameter loopmode type is invalid');
    }
    if(isNaN(loopmode) || loopmode < -1) {
        throwException(Widget.ExceptionTypes.INVALID_PARAMETER,'The input repeatTimes is invalid');
    }
    
    var fileUrl = gSoundFiles[soundID];
    //alert("play:" + fileUrl + soundID);
    var query = "fileUrl=" + Widget_encode(fileUrl)+"&loopmode="+ Widget_encode(loopmode);
    var aUrl = "aiduoniu023:///Multimedia/SoundPool/play?" + query;
    window.WebViewJavascriptBridge.send(aUrl, function(responseData) {
                                        log('JS got response', responseData)
                                        });
    
	return soundID;

}

function SoundPool_stop(streamID) {
    //alert("Sound Pool stop!");
}


